from setuptools import setup

setup(
    name="chappie",
    version="0.0.1",
    description="Minimal Finite State Machine",
    url="https://github.com/frodsan/chappie",
    author="Francesco Rodríguez",
    author_email="frodsan@protonmail.com",
    license="MIT",
    packages=["chappie"],
    zip_safe=False
)
